# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Text-CSV_XS
Version:	1.56
Release:	1.%{__distinit}%{__distvers}
Summary:	Comma-separated values manipulation routines
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Text-CSV_XS
Source0:	https://cpan.metacpan.org/modules/by-module/Text/Text-CSV_XS-%{version}.tgz
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	gcc
BuildRequires:	make
BuildRequires:	perl-devel
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(charnames)
BuildRequires:	perl(Config::Tiny)
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Encode)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(IO::Handle)
BuildRequires:	perl(strict)
BuildRequires:	perl(UNIVERSAL::isa)
BuildRequires:	perl(vars)
BuildRequires:	perl(warnings)
BuildRequires:	perl(XSLoader)
# Test Suite
BuildRequires:	perl(base)
BuildRequires:	perl(Config)
BuildRequires:	perl(Test::More)
BuildRequires:	perl(Tie::Scalar)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Encode)
Requires:	perl(IO::Handle)
Requires:	perl(UNIVERSAL::isa)

# Don't "provide" private perl objects
%{?perl_default_filter}

%description
Text::CSV provides facilities for the composition and decomposition of
comma-separated values. An instance of the Text::CSV class can combine
fields into a CSV string and parse a CSV string into fields.

%prep
%setup -q -n Text-CSV_XS-%{version}

# Fix perl location in example scripts
perl -pi -e 's|^#!/pro/bin/perl|#!/usr/bin/perl|' \
	examples/{csv-check,parser-xs.pl,csvdiff,csv2xls,csv2xlsx,rewrite.pl}

# Turn off exec bits in examples to avoid a multitude of docfile dependencies
chmod -c a-x examples/*

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
find %{buildroot} -type f -name '*.bs' -empty -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%doc ChangeLog CONTRIBUTING.md README examples/
%{perl_vendorarch}/Text/
%{perl_vendorarch}/auto/Text/
%{_mandir}/man3/Text::CSV_XS.3*

%changelog
* Sun Aug 11 2024 Paul Howarth <paul@city-fan.org> - 1.56-1
- Update to 1.56 (rhbz#2303862)
  - Yet another strict/comment_str conflict (GH#57)
  - Strict affected by column_names

* Tue Jun 18 2024 Paul Howarth <paul@city-fan.org> - 1.55-1
- Update to 1.55 (rhbz#2292859)
  - More fixes for strict under bind_columns (GH#54)
  - Strict won't hide previous error (GH#56)
  - Update to Devel::PPPort-3.72

* Thu Jun 13 2024 Paul Howarth <paul@city-fan.org> - 1.54-2
- Perl 5.40 rebuild

* Fri Apr 19 2024 Paul Howarth <paul@city-fan.org> - 1.54-1
- Update to 1.54 (rhbz#2275976)
  - It's 2024
  - Fix comment_str with strict
  - Documentation fixes (CPAN RT#150757, CPAN RT#151546)

* Thu Nov 23 2023 Paul Howarth <paul@city-fan.org> - 1.53-1
- Update to 1.53 (rhbz#2251219)
  - Two casts for -Wformat (GH#50)
  - Add --skip-empty to csv2xlsx
  - Add --font and --font-size to csv2xlsx
  - Fix skip_empty_rows ("skip") and trailing newlines (GH#52)
  - Fix comment in last line (CPAN RT#150501)

* Thu Sep 21 2023 Paul Howarth <paul@city-fan.org> - 1.52-1
- Update to 1.52 (rhbz#2240080)
  - Fix possible coredump in cache on non-IO parse (GH#49)

* Tue Aug  8 2023 Paul Howarth <paul@city-fan.org> - 1.51-1
- Update to 1.51 (rhbz#2229806)
  - Contact e-mail update
  - Attribute skip_empty_rows extended
  - Fix comments (GH#45)
  - Fix help (GH#46)
  - Update to Devel::PPPort-3.71
  - Fix HTML on Windows
  - Fix double header-interpretation on bom + headers => "auto" (GH#47)

* Wed Jul 12 2023 Paul Howarth <paul@city-fan.org> - 1.50-2
- Perl 5.38 rebuild

* Wed Mar  1 2023 Paul Howarth <paul@city-fan.org> - 1.50-1
- Update to 1.50
  - Promote sep to sep_set in csv() with auto-headers
  - Fix bug in set_diag surfaced by PERL_RC_STACK

* Tue Jan  3 2023 Paul Howarth <paul@city-fan.org> - 1.49-1
- Update to 1.49
  - csv2xlsx --split=CxP [--split-label=C]
  - Full documentation/manual for csv2xlsx
  - Fix non-integer arguments to getline_all (GH#39)
  - It's 2023
- Use SPDX-format license tag

* Wed Jun  1 2022 Paul Howarth <paul@city-fan.org> - 1.48-2
- Perl 5.36 rebuild

* Wed May 25 2022 Paul Howarth <paul@city-fan.org> - 1.48-1
- Update to 1.48
  - It's 2022
  - kh => 1 (use internal headers)
  - Add constants for META flags (CPAN RT#142508)
  - Update to Devel::PPPort-3.68
  - Export :CONSTANTS
  - Fix sep_set typo (GH#37)
  - Tested against perl-5.36.0

* Wed Dec 22 2021 Paul Howarth <paul@city-fan.org> - 1.47-1
- Update to 1.47
  - Make error 2014 catchable
  - Suppress empty lines on empty input (GH#34)
  - Perl 6 → Raku in docs (CPAN RT#136864)
  - IETF changed their URLs
  - Add some documentation for Google hist

* Sat May 22 2021 Paul Howarth <paul@city-fan.org> - 1.46-2
- Perl 5.34 rebuild

* Wed Mar 24 2021 Paul Howarth <paul@city-fan.org> - 1.46-1
- Update to 1.46
  - It's 2021
  - New attribute comment_str (RFC 4180-bis)
  - New attribute skip_empty_rows (RFC 4180-bis)
  - http → https in links in docs
  - Fix several issues with auto-detecting \r as EOL
  - Tested on perl-5.6.1 .. perl-5.32.1 and perl-5.33.8 (145)

* Thu Dec 24 2020 Paul Howarth <paul@city-fan.org> - 1.45-1
- Update to 1.45
  - Update to Devel::PPPort-3.62
  - Allow adding to existing data in csv (out => $ref)
  - examples/csv2xlsx: -L # to limit records to export
  - examples/csv2xlsx: --de # for possible double-encoding fix
  - examples/csv2xlsx: Check if .xlsx is creatable before conversion
  - Add examples/csv-split
  - Small documentation additions
  - Fix META issue for bug tracker

* Thu Jul 23 2020 Paul Howarth <paul@city-fan.org> - 1.44-1
- Update to 1.44
  - EBCDIC now fully functional
  - Prevent false negative CPANTESTERS fail reports
  - Fully tested on perl-5.32.0 and perl-5.33.0
  - Fix partly decoded fields in header

* Fri Jun 26 2020 Paul Howarth <paul@city-fan.org> - 1.43-2
- Perl 5.32 rebuild

* Wed May 27 2020 Paul Howarth <paul@city-fan.org> - 1.43-1
- Update to 1.43
  - Add --parser-opt[=value] to csv-check
  - Add -L and -X to csv-check
  - Fix undef value in attribute setters for strings (GH#24)
  - Document quote (undef) is not supported

* Tue May 19 2020 Paul Howarth <paul@city-fan.org> - 1.42-1
- Update to 1.42
  - Update to Devel::PPPort-3.58
  - Unicode fixes for csv2xls and csv2xlsx
  - Add internal buffers to cache diagnostics
  - Fix positional reporting in examples/csv-check
  - Allow passing CSV parsing attributes to csv-check
  - Proof reading - doc fixes by Klaus Baldermann <soonix> (GH#21)
  - Fix type caching (CPAN RT#132344)
  - Small doc fix by Nick Tonkin <1nickt> (GH#22)
  - Fix sep=; being ignored in ->header (GH#23)

* Sun Feb 16 2020 Paul Howarth <paul@city-fan.org> - 1.41-1
- Update to 1.41
  - Update to Devel::PPPort-3.56
  - csv2xls uses sheetname as csv2xlsx
  - csv2xlsx: support images (each image gets its own tab)
  - More docs (data validation)
  - It's 2020
  - No binary literals in fixed error messages
  - Fix auto_diag > 2 to die when headers are used (GH#19)

* Sun Sep 15 2019 Paul Howarth <paul@city-fan.org> - 1.40-1
- Update to 1.40
  - Update to Devel::PPPort-3.52
  - Development perl is now 5.28.2
  - [csv2xlsx] sheetnames are restricted to 31 characters
  - Generate cpanfile
  - Add munge type "db"
  - [csv2xls/csv2xlsx] do not generate xls/xlsx on empty CSV (GH#18)
  - New: support $csv->formula (sub { ... })
  - Support stacked encodings

* Mon Jun  3 2019 Paul Howarth <paul@city-fan.org> - 1.39-2
- Perl 5.30 rebuild

* Sat Mar 16 2019 Paul Howarth <paul@city-fan.org> - 1.39-1
- Update to 1.39
  - It's 2019
  - Fix tests to skip on Encode failing (GH#17)
  - Tested on Z/OS (s390x - Hercules)
  - Test with new Module::CPANTS::Analyse
  - Add options -w/-b/-Z to csvdiff
  - Fix strict on streaming EOF
  - Now also tested with cperl

* Wed Jan  2 2019 Paul Howarth <paul@city-fan.org> - 1.38-1
- Update to 1.38
  - Name the duplicate headers on error 1013
  - Add missing attributes to default list (documentation only)
  - Add support for combined keys
  - Look at $NO_COLOR for csvdiff
  - Add support for key-value pair

* Thu Sep 27 2018 Paul Howarth <paul@city-fan.org> - 1.37-1
- Update to 1.37
  - Moved pod-tests from t to xt
  - Add munge as alias for munge_column_names
  - Update to Devel::PPPort-3.43
  - Simplified ref-check defines in XS (GH#12)
  - Tested against perl-5.29.3

* Thu Jun 28 2018 Paul Howarth <paul@city-fan.org> - 1.36-2
- Perl 5.28 rebuild

* Tue Jun 26 2018 Paul Howarth <paul@city-fan.org> - 1.36-1
- Update to 1.36
  - Now also tested on FreeBSD-11.1
  - Update to Devel::PPPort-3.42
  - Fixed memory leak
  - Add undef_str attribute
  - Tested against perl-5.28.0
  - Move from DynaLoader to XSLoader
  - Tested on Synology DSM
- Switch upstream from search.cpan.org to metacpan.org

* Wed Mar 21 2018 Paul Howarth <paul@city-fan.org> - 1.35-1
- Update to 1.35
  - Remove META.yml from MANIFEST.skip
  - Use UNIVERSAL::isa to protect against unblessed references
  - Fix -Wformat warning (CPAN RT#123729)
  - Make detect_bom result available
  - It's 2018
  - Add csv (out => \"skip") - suppress output deliberately
  - Allow sub as top-level filter
  - Tested against Test2::Harness-0.001062 (yath test)
  - Tested against perl-5.27.10

* Mon Nov  6 2017 Paul Howarth <paul@city-fan.org> - 1.34-1
- Update to 1.34
  - Bad arg for formula (like "craok") will now die with error 1500
  - Row report in formula reporting was off by 1
  - Add a prominent section about BOM handling
  - Make sheet label more portable (csv2xlsx)
  - Allow munge => \%%hash
  - Preserve first row in csv (set_column_names => 0)

* Fri Oct 20 2017 Paul Howarth <paul@city-fan.org> - 1.33-1
- Update to 1.33
  - Small additional fix for eol = \r + BOM
  - Updated documentation for example files
  - Add support for formula actions (GH#11)
    - csv2xls and csv2xlsx now warn by default
  - Reset file info on ->header call (CPAN RT#123320)

* Sun Sep 17 2017 Paul Howarth <paul@city-fan.org> - 1.32-1
- Update to 1.32
  - Add keep_headers attribute to csv()
  - Fix on_in when used in combination with key
  - Fail on invalid arguments to csv
  - Fix header method on EOL = CR (CPAN RT#122764)

* Sun Aug  6 2017 Paul Howarth <paul@city-fan.org> - 1.31-3
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl

* Thu Jun 15 2017 Paul Howarth <paul@city-fan.org> - 1.31-1
- Update to 1.31
  - Fix already decoded BOM in headers
  - New options in csv-check
  - Some perlcritic
  - "escape" is alias for "escape_char" for consistency
  - Code cleanup and more tests (Devel::Cover)
  - Improve csv-check auto-sep-detection

* Sat Jun 10 2017 Paul Howarth <paul@city-fan.org> - 1.30-1
- Update to 1.30
  - Add csv (..., out => ...) syntax examples (GH#7)
  - Disable escape_null for undefined escape_char
  - Fix ->say for bound columns (CPAN RT#121576)
  - Update to Devel::PPPort 3.36
  - Tested under 5.26.0 and 5.27.0
  - Documentation changes and additions

* Wed Apr 26 2017 Paul Howarth <paul@city-fan.org> - 1.29-1
- Update to 1.29
  - More docs for bind_columns (CPAN RT#121350)
  - New attribute "strict" (also addresses CPAN RT#121350)
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - BR: perl-devel unconditionally

* Wed Mar 22 2017 Paul Howarth <paul@city-fan.org> - 1.28-1
- Update to 1.28
  - Fix length problem with bound empty fields and UTF-8 (CPAN RT#120655)

* Fri Mar  3 2017 Paul Howarth <paul@city-fan.org> - 1.27-1
- Update to 1.27
  - Remove unneeded done_testing
  - Attribute sep/sep_char is not allowed to be undefined
  - Increased test coverage: added errors 1008 and 1014
  - Default for escape_null in csv() is now false
  - It's 2017
  - New error code for illegal argument(s)/parameter(s) (CPAN RT#119827)
  - Fix tests for perl without dot in @INC
  - Fix crlf issue for csv() on Windows (CPAN RT#120466)

* Wed Nov 30 2016 Paul Howarth <paul@city-fan.org> - 1.26-1
- Update to 1.26
  - Disable some Unicode-related tests for unhealthy $PERL_UNICODE
    (CPAN RT#117856)
  - is_missing(0) on empty line returns 1 for keep_meta_info=true (GH#27)
- Add patch to let test suite work with Test::More < 0.88

* Mon Aug 29 2016 Paul Howarth <paul@city-fan.org> - 1.25-1
- Update to 1.25
  - Allow lc, uc, and coderef for csv() headers attribute
  - Document for eof when the last line has an error (CPAN RT#115954)
  - Allow csv() to call header() with all supported arguments
  - Add some docs for bind_columns

* Sat Jul  9 2016 Paul Howarth <paul@city-fan.org> - 1.24-1
- Update to 1.24
  - Fix typo in docs example code (GH#4)
  - Set auto-wrap on for csv2xls with embedded newlines
  - Add examples/csv2xlsx, the MSExcel-2007+ version of csv2xls; includes new
    feature to merge multiple CSV's into a single xlsx
  - Slight modification in examples
  - Fix parse error in complex option combo (CPAN RT#115953)
- BR: perl-generators where available
- Simplify find commands using -delete

* Sat Mar 26 2016 Paul Howarth <paul@city-fan.org> - 1.23-1
- Update to 1.23
  - Skip unsupported encodings
  - Reorganize Unicode section and mention layers
  - Amend some UTF-8 tests for PERL_UNICODE settings
  - Fix crash on error in parsing with bound columns (CPAN RT#113279)
  - Add predefined filters (not_blank, not_empty, filled)

* Wed Feb 24 2016 Paul Howarth <paul@city-fan.org> - 1.22-1
- Update to 1.22
  - Small doc updates regarding blank_is_undef
  - Precedence error in doc
  - Add new method header

* Wed Jan  6 2016 Paul Howarth <paul@city-fan.org> - 1.21-1
- Update to 1.21
  - Clarify documentation (CPAN RT#110941)
  - Alias %%_ to row in hashref mode for csv function attributes on_in and
    before_out
  - Examples now use defined-or and thus require perl-5.10 or up
  - Fix \r\n ending with allow_loose_escapes

* Fri Oct  9 2015 Paul Howarth <paul@city-fan.org> - 1.20-1
- Update to 1.20
  - Use "say" in synopsis
  - Remove needless special characters in doc section
  - Change doc =item attributes for new to =head for index
  - Add known_attributes function/method
  - Add contributor notes
  - Allow undef as value for aliased attributes
- Explicitly BR: perl-devel, needed for EXTERN.h

* Wed Jun 17 2015 Paul Howarth <paul@city-fan.org> - 1.19-1
- Update to 1.19
  - Guard tests against $PERL_UNICODE
  - Numeric options were sometimes interpreted as boolean
  - Safer meta_info use

* Sun May 24 2015 Paul Howarth <paul@city-fan.org> - 1.18-1
- Update to 1.18
  - Add quote_empty attribute
  - Add database NULL documentation
  - Inherit csv attributes in csv() when called in void context
  - Micro-optimisation for combine/print (empty fields will be faster)

* Sun Apr 26 2015 Paul Howarth <paul@city-fan.org> - 1.17-1
- Update to 1.17
  - Enable overruling $csv in csv()
  - Allow encoding to be shortened to enc in csv()
  - Allow filter to alter content
  - Add say (print with default eol => $\)
  - Allow MS sep=; on first line (CPAN RT#100304)

* Mon Mar  2 2015 Paul Howarth <paul@city-fan.org> - 1.16-1
- Update to 1.16
  - filter made more useful (access to other fields)

* Wed Feb 11 2015 Paul Howarth <paul@city-fan.org> - 1.15-1
- Update to 1.15
  - Remove perl recommendation from META as it breaks cpan clients

* Mon Feb  2 2015 Paul Howarth <paul@city-fan.org> - 1.14-1
- Update to 1.14
  - Move to github
  - Add csv (filter => {});
  - Change csv ()'s void context behaviour

* Mon Jan  5 2015 Paul Howarth <paul@city-fan.org> - 1.13-1
- Update to 1.13
  - Simplify code path for old perl
  - Fix quote_binary (CPAN RT#100676)
  - Fix csv() for hashrefs with aliased headers
  - Update copyright to 2015
- Classify buildreqs by usage
- Drop upstreamed UTF8 patch

* Sun Nov 16 2014 Paul Howarth <paul@city-fan.org> - 1.12-1
- Update to 1.12
  - Add field number to error_diag
  - Fixed non-IO parsing multi-byte EOL
  - Fixed a possible missed multi-byte EOL
  - Allow hashref for csv()'s headers attribute
  - Allow encoding on all output handles in csv()
  - Include doc changes as ticketed in the Text::CSV queue
  - Fix parallel testing issue
  - Allow csv as method call (not using the object)
  - Rename quote_null to escape_null
  - Give meaning to keep_meta_info on output (CPAN RT#99941)
- Add patch to recode documentation as UTF8
- Drop patch for building with Test::More < 0.82, no longer needed

* Mon Sep  1 2014 Paul Howarth <paul@city-fan.org> - 1.11-2
- Perl 5.20 rebuild

* Wed Aug 20 2014 Paul Howarth <paul@city-fan.org> - 1.11-1
- Update to 1.11
  - Fixed eof (CPAN RT#97742)
  - Check for attribute conflicts early
  - csv (in => [..]) now defaults to *STDOUT for out
  - Support for multi-byte quote_char
  - New attribute "key" for csv ()
- Add patch to support building with Test::More < 0.82

* Sun Aug 10 2014 Paul Howarth <paul@city-fan.org> - 1.10-1
- Update to 1.10
  - Support for scalar ref in out: csv (out => \(my $x = ""), ...)
  - Support for multi-byte sep_char
  - Simplified the cache coding

* Mon Jun  9 2014 Paul Howarth <paul@city-fan.org> - 1.09-1
- Update to 1.09
  - Missed defined-or need in csv2xls (CPAN RT#95787)

* Mon May 19 2014 Paul Howarth <paul@city-fan.org> - 1.08-1
- Update to 1.08
  - Documentation updates
  - Allow disjointed CSV cell fragment lists

* Tue Apr 29 2014 Paul Howarth <paul@city-fan.org> - 1.07-1
- Update to 1.07
  - Allow ref to scalar for csv (in => ...)
  - Allow CODE ref to in attribute
  - Allow * in fragment cellspec's bottom-right cell
- Drop %%defattr, redundant since rpm 4.4

* Fri Apr 25 2014 Paul Howarth <paul@city-fan.org> - 1.06-1
- Update to 1.06
  - Fix possible fail in tests on Windows
  - Only close file handles in csv() for files
  - New callbacks for csv()

* Thu Mar 13 2014 Paul Howarth <paul@city-fan.org> - 1.05-1
- Update to 1.05
  - Allow case insensitive attributes and attribute aliases
    (quote_always = always_quote)
  - Enhanced the csv() function (diagnostics)
  - Start callbacks support
  - Minor doc fixes
  - Make subclassing safer

* Thu Feb  6 2014 Paul Howarth <paul@city-fan.org> - 1.04-1
- Update to 1.04
  - get_columns() with no argument now returns the empty list instead of undef
    when no columns defined
  - Fragments (rcf7111) now also support AoH (was AoA only)
  - Error code conflict for fragments resolved to 2013
  - New function "csv" (not a method)
- Drop upstreamed done_testing patch

* Fri Jan 24 2014 Paul Howarth <paul@city-fan.org> - 1.03-1
- Update to 1.03
  - Implement RFC7111
- Patch out the need for Test::More ≥ 0.88

* Mon Nov 11 2013 Paul Howarth <paul@city-fan.org> - 1.02-1
- Update to 1.02
  - Add example for reading only a single column
  - Don't store NULL in _ERROR_INPUT (CPAN RT#86217)
  - Prevent double-decode in csv-check
  - Add decode_utf8 attribute (default is true)

* Wed Jul 17 2013 Paul Howarth <paul@city-fan.org> - 1.01-2
- Perl 5.18 rebuild

* Mon Jun 17 2013 Paul Howarth <paul@city-fan.org> - 1.01-1
- Update to 1.01
  - Cache not re-read on getline_all (CPAN RT#86155)

* Thu Jun 13 2013 Paul Howarth <paul@city-fan.org> - 1.00-1
- Update to 1.00
  - Fix automatic UTF-8 in getline/parse for SV's with \0

* Mon Jun 10 2013 Paul Howarth <paul@city-fan.org> - 0.99-1
- Update to 0.99
  - If no arguments are passed at all, bind_columns will return the list of
    current bindings or undef if no binds are active

* Mon Jun 10 2013 Paul Howarth <paul@city-fan.org> - 0.98-1
- Update to 0.98
  - Clarify eol documentation
  - Move error_input to XS

* Sun Mar 31 2013 Paul Howarth <paul@city-fan.org> - 0.97-1
- Update to 0.97
  - Regain the speed from 0.91 (buffer back to 1k)
  - Minor cleanup in XS code
  - Add diag_verbose attribute

* Wed Mar 27 2013 Paul Howarth <paul@city-fan.org> - 0.96-1
- Update to 0.96
  - No need to require Test::Harness since it's unused (CPAN RT#82693)
  - parse ("") should return one empty field, not undef
  - Now that we know the record number, show it in auto_diag

* Mon Jan 14 2013 Paul Howarth <paul@city-fan.org> - 0.95-1
- Update to 0.95
  - Introduce allow_unquoted_escape as workaround for CPAN RT#81295
  - Update copyright to 2013
  - Introduce print_hr() for CPAN RT#76143
  - Dropped plans to support EBCDIC

* Tue Dec  4 2012 Paul Howarth <paul@city-fan.org> - 0.94-1
- Update to 0.94
  - Guard against beta releases of Encode (CPAN RT#81499)
  - Fix sv_cache init global-buffer-overflow (CPAN RT#81469)
  - Tested with perl compiled with clang (also to verify CPAN RT#81469)
  - Fix memory leak (CPAN RT#81539)

* Mon Nov 19 2012 Paul Howarth <paul@city-fan.org> - 0.93-1
- Update to 0.93
  - Skip Encode related tests on too old Encode
  - Force old(er) tar format (ustar) - assumes GNU tar on release box
- BR: perl(Encode)

* Tue Nov 13 2012 Paul Howarth <paul@city-fan.org> - 0.92-1
- Update to 0.92
  - Allow bind_columns() for print()
  - Increase buffer size for print to 64k
  - Fix CPAN RT#80680 - Buffer break halfway through UTF8 characters

* Tue Aug 21 2012 Paul Howarth <paul@city-fan.org> - 0.91-1
- Update to 0.91
  - Prevent test-failures for long doubles on weird architectures
  - More UTF-8 tests for the change of 0.90
  - Update test case now 5.005 is not supported anymore
  - Rip out the tell/seek introduced in 0.90

* Tue Jul 10 2012 Paul Howarth <paul@city-fan.org> - 0.90-2
- Perl 5.16 rebuild

* Fri Jun 15 2012 Paul Howarth <paul@city-fan.org> - 0.90-1
- Update to 0.90
  - Drop 5.005 support (5.6.1 is now minimum)
  - Introduce record_number
  - Try harder to get the complete input parsed for the current record when
    hitting errors on parsing seekable IO (only works in 5.14.0 and up)
  - Tested with perl 5.6.1 .. 5.17.0 (99 versions of perl) on Linux, HP-UX,
    AIX, and Windows
  - SvSETMAGIC was missing for tied variables causing weird actions at a
    distance, e.g. in printf
  - UTF8 flag was not always reset when using bound variables

* Fri Mar 16 2012 Paul Howarth <paul@city-fan.org> - 0.88-1
- Update to 0.88
  - Fix for $/ in 0.86 broke parsing fields that contain excessive $/'s

* Thu Mar  8 2012 Paul Howarth <paul@city-fan.org> - 0.87-1
- Update to 0.87
  - Extra check on utf8 output (CPAN RT#74330)
  - examples/csvdiff now recognizes numerically sorted CSV files
  - Document example comparing getline_hr vs. bind_columns + getline
- Don't need to remove empty directories from buildroot
- Drop support for distributions prior to FC-3:
  - Don't need to define %%{perl_vendorarch}
  - Use DESTDIR rather than PERL_INSTALL_ROOT
  - Use %%{_fixperms} macro rather than our own chmod incantation

* Sun Jan 22 2012 Paul Howarth <paul@city-fan.org> - 0.86-1
- Update to 0.86
  - Introduce quote_binary attribute
  - Update copyright to 2012
  - Versions
  - Fixed a utf8::decode on undef (found by perl-5.15.7)
  - Fixed localized $/ interference with other handles (CPAN RT#74216)
- BR: perl(Carp) and perl(DynaLoader)

* Wed Sep  7 2011 Paul Howarth <paul@city-fan.org> - 0.85-1
- Update to 0.85
  - NAME / DISTNAME in Makefile.PL
  - More cross-checks for META data

* Sun Aug  7 2011 Paul Howarth <paul@city-fan.org> - 0.83-1
- Update to 0.83a
  - Fix spurious auto_diag warning (CPAN RT#69673)
  - Tested with 50 versions of perl, including 1.15.1

* Thu Jun 23 2011 Paul Howarth <paul@city-fan.org> - 0.82-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Sat May  7 2011 Paul Howarth <paul@city-fan.org> - 0.82-1
- Update to 0.82
  - Documentation fix (CPAN RT#66905)
  - Documentation overhaul (pod links)
- Drop UTF-8 recoding patch, applied upstream

* Wed Mar 23 2011 Paul Howarth <paul@city-fan.org> - 0.81-1
- Update to 0.81
  - Add is_missing ()
  - Doc overhaul
  - Fix build on OpenVMS (CPAN RT#65654)
  - Fix SetDiag () leak (CPAN RT#66453)
- Recode docs as UTF-8
- Nobody else likes macros for commands

* Sat Dec 25 2010 Paul Howarth <paul@city-fan.org> - 0.80-1
- Update to 0.80
  - Implement getline_all() and getaline_hr_all()
  - Fixed another parsing issue with eol = \r (CPAN RT#61525)

* Sat Nov 27 2010 Paul Howarth <paul@city-fan.org> - 0.79-1
- Update to 0.79
  - Version 0.77 broke MacOS exported CSV files with only \r
  - Use correct type for STRLEN (HP-UX/PA-RISC/32)
  - More code coverage
  - EOF unreliable when line-end missing at EOF

* Fri Nov 26 2010 Paul Howarth <paul@city-fan.org> - 0.77-1
- Update to 0.77
  - Internals now use warn() instead of (void)fprintf (stderr, ...)
  - The test in t/80_diag now passes on Windows
  - Better parsing for eol = \r and set as such (CPAN RT#61525)
  - Workaround for AIX cpp bug (CPAN RT#62388)

* Wed Oct 13 2010 Paul Howarth <paul@city-fan.org> - 0.76-1
- Update to 0.76
  - Windows doesn't support STDERR redirection as used in t/80_diag

* Fri Oct  8 2010 Paul Howarth <paul@city-fan.org> - 0.75-1
- Update to 0.75
  - Fixed undefinedness of $\ in print (CPAN RT#61880)

* Thu Sep 30 2010 Paul Howarth <paul@city-fan.org> - 0.74-1
- Update to 0.74
  - Spelling fixes
  - Real eol support for parsing streams (beyond \n, \r and \r\n)
  - Clarify doc for always_quote to not quote undef fields
  - Clarify UTF8 process for print () and combine ()

* Tue Aug 10 2010 Paul Howarth <paul@city-fan.org> - 0.73-1
- Import from Fedora
- DESTDIR => PERL_INSTALL_ROOT for EL-3 compatibility
- Update to 0.73
  - Improve date conversion in examples/csv2xls
	new option -D allows column selection for date conversions
  - Tested under perl-5.12.0 (and 21 other versions of perl)
  - Added a note about EBCDIC data files
  - Test suite is now safe for parallel test (prove --shuffle -j6)

* Fri May 07 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.72-2
- Mass rebuild with perl-5.12.0

* Wed Mar 17 2010 Chris Weyl <cweyl@alumni.drew.edu> - 0.72-1
- PERL_INSTALL_ROOT => DESTDIR, add perl_default_filter (XS module)
- Auto-update to 0.72 (by cpan-spec-update 0.01) (DBIx::Class needed a newer
  Text::CSV, which in turn can only leverage Text::CSV_XS >= 0.70)
- Added a new br on perl(ExtUtils::MakeMaker) (version 0)
- Added a new br on perl(IO::Handle) (version 0)
- Added a new br on perl(Test::Harness) (version 0)
- Added a new br on perl(Test::More) (version 0)
- Added a new br on perl(Tie::Scalar) (version 0)

* Fri Dec  4 2009 Stepan Kasal <skasal@redhat.com> - 0.69-2
- Rebuild against perl 5.10.1

* Mon Nov  2 2009 Stepan Kasal <skasal@redhat.com> - 0.69
- New upstream release

* Wed Oct  7 2009 Marcela Mašláňová <mmaslano@redhat.com> - 0.68-1
- Update to new upstream release

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.58-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.58-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Dec 10 2008 Lubomir Rintel <lkundrak@v3.sk> - 0.58-1
- Update to latest upstream
- SvUPGRADE patch upstreamed

* Tue Jul 08 2008 Lubomir Rintel <lkundrak@v3.sk> - 0.52-2
- Actually solving the issue mentioned in previous change

* Tue Jul 08 2008 Lubomir Rintel <lkundrak@v3.sk> - 0.52-1
- Updated to 0.52 to solve an issue with perl 5.10

* Wed Feb 27 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.30-5
- Rebuild for perl 5.10 (again)

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.30-4
- Autorebuild for GCC 4.3

* Sat Feb  2 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.30-3
- Rebuild for new perl

* Wed Aug 29 2007 Fedora Release Engineering <rel-eng at fedoraproject dot org> - 0.30-2
- Rebuild for selinux ppc32 issue

* Sat Jun 23 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.30-1
- Update to 0.30

* Sat Jun 16 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.29-1
- Update to 0.29

* Sat Jun 16 2007 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.27-1
- Update to 0.27
- New upstream maintainer

* Thu Sep  7 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.23-5
- Rebuild for FC6

* Wed Feb 22 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.23-4
- Rebuild for FC5 (perl 5.8.8)

* Wed Feb 22 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.23-3
- The wonders of CVS problems (released skipped)

* Thu Jan  5 2006 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.23-2
- Build section: simplified RPM_OPT_FLAGS handling (#175898)

* Sat Nov 05 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.23-1
- First build
